import { defineProperty as _defineProperty } from './_virtual/_rollupPluginBabelHelpers.mjs';
import { UmiError } from '@metaplex-foundation/umi-core';

class WalletAdaptersError extends UmiError {
  constructor(message, cause) {
    super(message, 'plugin', 'Wallet Adapters', cause);
    _defineProperty(this, "name", 'WalletAdaptersError');
  }
}
class UninitializedWalletAdapterError extends WalletAdaptersError {
  constructor() {
    const message = `The current wallet adapter is not initialized. ` + 'You likely have selected a wallet adapter but forgot to initialize it. ' + 'You may do this by running the following asynchronous method: "wallet.connect();".';
    super(message);
    _defineProperty(this, "name", 'UninitializedWalletAdapterError');
  }
}
class OperationNotSupportedByWalletAdapterError extends WalletAdaptersError {
  constructor(operation) {
    const message = `The current wallet adapter does not support the following operation: [${operation}]. ` + 'Ensure your wallet is connected using a compatible wallet adapter.';
    super(message);
    _defineProperty(this, "name", 'OperationNotSupportedByWalletAdapterError');
  }
}

export { OperationNotSupportedByWalletAdapterError, UninitializedWalletAdapterError, WalletAdaptersError };
//# sourceMappingURL=errors.mjs.map
